@@ -28,10 +28,11 @@ from fixtures import Fixture, TempDir
 from testtools.content import content_from_file
 
 
-def countdown(duration=5.0, sleep=0.1):
+def countdown(duration=60, sleep=0.1):
     """Provide a countdown iterator that sleeps between iterations.
 
-    Yields the current iteration count, starting from 1.
+    Yields the current iteration count, starting from 1.  The duration can be
+    in fractional seconds.
     """
     start = time.time()
     stop = start + duration
